class CollarColumn:
    HOLEID = 'holeid'
    PROJECTID = 'projectid'
    X = 'x'
    Y = 'y'
    Z = 'z'
    TDEPTH = 'tdepth'
    PROSPECT = 'prospect'

class SurveyColumn:
    HOLEID = 'holeid'
    PROJECTID = 'projectid'
    DEPTH = 'depth'
    AZIMUTH = 'azimuth'
    DIP = 'dip'

class AlterationColumn:
    HOLEID = 'holeid'
    PROJECTID = 'projectid'
    FROM = 'from'
    TO = 'to'

class AssayColumn:
    HOLEID = 'holeid'
    PROJECTID = 'projectid'
    SAMPLEID = 'sampleid'
    FROM = 'from'
    TO = 'to'

class LithoColumn:
    HOLEID = 'holeid'
    PROJECTID = 'projectid'
    FROM = 'from'
    TO = 'to'

class MineralisationColumn:
    HOLEID = 'holeid'
    PROJECTID = 'projectid'
    FROM = 'from'
    TO = 'to'